pub trait OpenApiInputsAlg {
// Required method
fn describe(schema: &JsonSchemaShape) -> Vec<OpenApiArgument>;
}Expand description
Describes the whole argument product one endpoint states, in declaration order.
Required Methods
Sourcefn describe(schema: &JsonSchemaShape) -> Vec<OpenApiArgument>
fn describe(schema: &JsonSchemaShape) -> Vec<OpenApiArgument>
Describes each argument, in the order the declaration reads them.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".